cmd

package
v0.0.0-...-b19803f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 20, 2021 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func NewCmdGrabber

func NewCmdGrabber(logger *log.Entry) *cobra.Command

Types

type GrabberOptions

type GrabberOptions struct {
	DirectoryHandler directory.IHandler
	ComposeHandler   composeFile.IHandler
	Directory        string
	Port             string
	// contains filtered or unexported fields
}

func NewGrabberOptions

func NewGrabberOptions() GrabberOptions

func (*GrabberOptions) Complete

func (o *GrabberOptions) Complete(logger *log.Entry)

func (GrabberOptions) Run

func (o GrabberOptions) Run()

Jump to